***********************
Directed Acyclic Graphs
***********************

.. automodule:: networkx.algorithms.dag
.. autosummary::
   :toctree: generated/

   topological_sort
   topological_sort_recursive
   is_directed_acyclic_graph
   is_aperiodic
